# extra-pydantic

[![License](https://img.shields.io/pypi/l/extra-pydantic.svg?color=green)](https://github.com/brisvag/extra-pydantic/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/extra-pydantic.svg?color=green)](https://pypi.org/project/extra-pydantic)
[![Python Version](https://img.shields.io/pypi/pyversions/extra-pydantic.svg?color=green)](https://python.org)
[![CI](https://github.com/brisvag/extra-pydantic/actions/workflows/ci.yml/badge.svg)](https://github.com/brisvag/extra-pydantic/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/brisvag/extra-pydantic/branch/main/graph/badge.svg)](https://codecov.io/gh/brisvag/extra-pydantic)

Better and more consistent pydantic support for (parametrized) generics, custom builtin-like classes, protocols, dataclasses.
